CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
50 lines
1.5 KiB
Plaintext
50 lines
1.5 KiB
Plaintext
// Test that HIP PGO doesn't crash on multi-GPU systems.
|
|
// The profile runtime should only collect from the active device at exit,
|
|
// not iterate all devices (which can trigger comgr lazy-load crashes).
|
|
//
|
|
// REQUIRES: hip, amdgpu
|
|
// RUN: %clang -x hip -fprofile-instr-generate -fcoverage-mapping \
|
|
// RUN: --offload-arch=%amdgpu_arch %s -o %t -L%hip_lib_path -lamdhip64
|
|
// RUN: env LLVM_PROFILE_FILE=%t.profraw \
|
|
// RUN: LD_LIBRARY_PATH=%hip_lib_path:$LD_LIBRARY_PATH \
|
|
// RUN: LLVM_PROFILE_VERBOSE=1 %run %t 2>&1 | FileCheck %s
|
|
//
|
|
// Verify device 0 data was collected and program didn't crash.
|
|
// CHECK: Collecting static profile data from device 0
|
|
// CHECK: Successfully wrote device profile using shared API
|
|
// CHECK: PASS
|
|
|
|
#include <hip/hip_runtime.h>
|
|
#include <cstdio>
|
|
|
|
__global__ void add_one(int *data, int n) {
|
|
int idx = blockIdx.x * blockDim.x + threadIdx.x;
|
|
if (idx < n)
|
|
data[idx] += 1;
|
|
}
|
|
|
|
int main() {
|
|
int ndev = 0;
|
|
(void)hipGetDeviceCount(&ndev);
|
|
|
|
constexpr int N = 32;
|
|
int h_data[N];
|
|
for (int i = 0; i < N; ++i) h_data[i] = i;
|
|
|
|
int *d_data;
|
|
(void)hipMalloc(&d_data, N * sizeof(int));
|
|
(void)hipMemcpy(d_data, h_data, N * sizeof(int), hipMemcpyHostToDevice);
|
|
|
|
add_one<<<1, N>>>(d_data, N);
|
|
|
|
(void)hipMemcpy(h_data, d_data, N * sizeof(int), hipMemcpyDeviceToHost);
|
|
(void)hipFree(d_data);
|
|
|
|
int ok = 1;
|
|
for (int i = 0; i < N; ++i)
|
|
if (h_data[i] != i + 1) ok = 0;
|
|
|
|
printf("%s (devices=%d)\n", ok ? "PASS" : "FAIL", ndev);
|
|
return !ok;
|
|
}
|